@@ -9,6 +9,9 @@ from turbogears.identity.soprovider import TG_User, TG_Group, TG_Permission
 #hub = database.AutoConnectHub("sqlite:///:memory:")
 hub = database.PackageHub("turbogears.identity")
 
+def mycustomencrypt(password):
+    return password+'_custom'
+
 class RestrictedArea(turbogears.controllers.Controller, identity.SecureResource):
 
     require = identity.in_group('peon')
@@ -108,7 +111,6 @@ class IdentityRoot(turbogears.controllers.RootController):
         return '%s %s' % (user_name, password)
     new_user_setup = turbogears.expose()(new_user_setup)
 
-
 class TestIdentity(unittest.TestCase):
 
     def setUp(self):
@@ -280,6 +282,21 @@ class TestIdentity(unittest.TestCase):
         hub.rollback()
         hub.end()
         
+    def test_user_password_hashed_custom(self):
+        "Test if a custom hashed password is stored in the database."
+        config.update({'identity.soprovider.encryption_algorithm':'custom'})
+        config.update({'identity.custom_encryption':'identity.tests.test_identity.mycustomencrypt'})
+        # force new config values to load
+        startup.startTurboGears()
+        testutil.create_request('/')
+        hub.begin()
+        u = TG_User.by_user_name('samIam')
+        u.password = 'password'
+        u.sync()
+        assert u.password =='password_custom'
+        hub.rollback()
+        hub.end()
+
     def test_anonymous_browsing(self):
         "Test if we can show up anonymously."
         testutil.create_request('/')
